VIBE ARCADE

## NEON SNAKE

Classic snake with a synthwave twist.

STATUS: READY
Launch

## SEA MINESWEEPER

Navigate the deep waters. Avoid the mines.

STATUS: READY
Launch

## FOREST TIC-TAC-TOE

Nature-themed classic. X vs O in the wild.

STATUS: READY
Launch

## SYNTHWAVE TYPING

Type fast to the beat. Test your skills.

STATUS: READY
Launch

## NEON STAR BLASTER

Blast through enemies. Defend the galaxy.

STATUS: READY
Launch